<?php
namespace wcf\form;
use wcf\data\category\CategoryNodeTree;
use wcf\data\user\UserEditor;
use wcf\system\category\CategoryHandler;
use wcf\system\exception\NamedUserException;
use wcf\system\request\LinkHandler;
use wcf\system\user\collapsible\content\UserCollapsibleContentHandler;
use wcf\system\WCF;
use wcf\util\HeaderUtil;

/**
 * Shows the terms of use form.
 * 
 * @author	Sascha Greuel <sascha@softcreatr.de>
 * @copyright	2013 Sascha Greuel
 * @license	Creative Commons Attribution-NoDerivatives <http://creativecommons.org/licenses/by-nd/4.0/legalcode>
 * @package	be.bastelstu.sascha.termsofuse
 * @subpackage	form
 * @category	Community Framework
 */
class TermsForm extends AbstractForm {
	/**
	 * @see	\wcf\page\AbstractPage::$enableTracking
	 */
	public $enableTracking = true;
	
	/**
	 * @see	\wcf\page\AbstractPage::$neededModules
	 */
	public $neededModules = array('MODULE_USER_TERMS_OF_USE');
	
	/**
	 * @see	\wcf\page\AbstractPage::$templateName
	 */
	public $templateName = 'terms';
	
	/**
	 * @see	\wcf\page\AbstractPage::$activeMenuItem
	 */
	public $activeMenuItem = 'wcf.footer.menu.termsOfUse';
	
	/**
	 * true, if the user has accepted the terms of use
	 * @var	boolean
	 */
	public $accept = false;
	
	/**
	 * user is about to register
	 * @var	boolean
	 */
	public $aboutToRegister = false;
	
	/**
	 * category object type object
	 * @var	\wcf\data\object\type\ObjectType
	 */
	public $objectType = null;
	
	/**
	 * category node tree
	 * @var	\wcf\data\category\CategoryNodeTree
	 */
	public $categoryNodeTree = null;
	
	/**
	 * @see	\wcf\page\IPage::readParameters()
	 */
	public function readParameters() {
		parent::readParameters();
		
		if (!WCF::getUser()->userID) {
			if (REGISTER_DISABLED) {
				throw new NamedUserException(WCF::getLanguage()->get('wcf.user.register.error.disabled'));
			}
		}
		
		if (isset($_REQUEST['aboutToRegister'])) $this->aboutToRegister = true;
	}
	
	/**
	 * @see	\wcf\form\IForm::readFormParameters()
	 */
	public function readFormParameters() {
		parent::readFormParameters();
		
		if (isset($_POST['accept'])) $this->accept = true;
	}
	
	/**
	 * @see	\wcf\form\IForm::validate()
	 */
	public function validate() {
		parent::validate();
		
		if (!$this->accept) throw new UserInputException('accept');
	}
	
	/**
	 * @see	\wcf\page\IPage::readData()
	 */
	public function readData() {
		parent::readData();
		
		$this->objectType = CategoryHandler::getInstance()->getObjectTypeByName('be.bastelstu.sascha.termsofuse.term');
		$this->buildCategoryNodeTree();
	}
	
	/**
	 * @see	\wcf\form\IForm::save()
	 */
	public function save() {
		parent::save();
		
		WCF::getSession()->register('disclaimerAccepted', true);
		$this->saved();
		WCF::getSession()->update();
		
		if (!WCF::getUser()->userID) {
			HeaderUtil::redirect(LinkHandler::getInstance()->getLink('Register'));
		} else {
			$userEditor = new UserEditor(WCF::getUser());
			$userEditor->update(array(
				'disclaimerAccepted' => 1,
				'quitStarted' => 0
			));
			
			HeaderUtil::redirect(LinkHandler::getInstance()->getLink());
		}
		
		exit;
	}
	
	/**
	 * @see	\wcf\page\IPage::assignVariables()
	 */
	public function assignVariables() {
		parent::assignVariables();
		
		WCF::getTPL()->assign(array(
			'terms' => $this->categoryNodeTree->getIterator(),
			'aboutToRegister' => $this->aboutToRegister,
			'sidebarCollapsed' => UserCollapsibleContentHandler::getInstance()->isCollapsed('com.woltlab.wcf.collapsibleSidebar', 'be.bastelstu.sascha.termsofuse.TermsOfUseForm'),
			'sidebarName' => 'be.bastelstu.sascha.termsofuse.TermsOfUseForm',
		));
	}
	
	/**
	 * Reads available terms.
	 */
	protected function buildCategoryNodeTree() {
		$this->categoryNodeTree = new CategoryNodeTree($this->objectType->objectType, 0, false);
	}
}
